import java.awt.Shape;
import java.awt.geom.GeneralPath;
import java.util.ArrayList;
import java.util.Iterator;

/**
 * Eine Schrankwand, der manipuliert werden kann und sich selbst auf einer Leinwand zeichnet.
 * 
 * @author Claus Albowski
 * @version 2.3  (sept 07)
 */
public class Schrankwand extends Moebel
{
    private ArrayList<Schrank> schraenke = new ArrayList<Schrank>();
    private int anzahl;

    /**
     * Erzeuge eine neue Schrankwand mit einer Standardfarbe und Standardgroesse
     * an einer Standardposition. (Standardkonstruktor)
     */
    public Schrankwand(int anzahl) {
        xPosition = 10;
        yPosition = 10;
        farbe = "schwarz";
        orientierung = 0;
        istSichtbar = false;
        breite = anzahl*60;
        tiefe  = 37;
        this.anzahl = anzahl;
        init();
    }
    
    /**
     * Erzeuge eine neue Schrankwand aus anzahl Elementen.
     * Als Breite ist die Breite der einzelnen Schrankelemente einzugeben.
     */
    public Schrankwand(int anzahl,
                int xPosition,
                int yPosition,
                String farbe,
                int orientierung,
                int breite,
                int tiefe) {
        this.xPosition = xPosition;
        this.yPosition = yPosition;
        this.farbe = farbe;
        this.orientierung = orientierung;
        istSichtbar = false;
        this.breite = anzahl*breite;
        this.tiefe  = tiefe;
        this.anzahl = anzahl;
        init();
    }
    
    /**
     * initialisiert die Schrankobjekte, aus denen die Schrankwand besteht.
     */
    private void init(){
        for (int i=0;i<anzahl;i++)
        schraenke.add(new Schrank(i*breite/anzahl, 0, farbe, orientierung, breite/anzahl, tiefe));
    }
    
    /**
     * Berechnet das zu zeichnende Shape anhand der gegebenen Daten
     */
    protected Shape gibAktuelleFigur() {
        // einen GeneralPath definieren
        GeneralPath schrankwand = new GeneralPath();
        for (Iterator<Schrank> it= schraenke.iterator(); it.hasNext();)
        schrankwand.append(it.next().gibAktuelleFigur(), false);
        return transformiere(schrankwand);
    }
}
